# pybullet_suite

Useful pybullet wrapper functions. (heavily under development)


pybullet_suite
======================

`pybullet_suite` is a useful pybullet wrapper functions. (heavy develoment!).

## Dependency
numpy, scipy, trimesh

## Install
`pip install pybullet_suite`
  

## Usage
Refer to test.py
  
## Robot
Franka Emika Panda, Panda-gripper, Panda-dualarm are available

## Add your own controller
TBD

## Add your own robot
TBD
